import React, { useState, useEffect, useRef, Fragment } from "react";
import { Row, Col, Space } from 'antd';
import TableView from '@/components/TableView';
import * as $$ from '../../utils/utility';
import { useNavigate } from 'react-router-dom';
export default function KeyVisits({ labelInfo, data, fakeData, search, handleChangePage }) {
  const colorList = ['#C64FBE', '#D8A247', '#B82F6E', '#199C8F', '#3ECB7A', '#117AC1', '#6865D7', '#2661CE']
  const navigate = useNavigate();
  const tagList = labelInfo?.map((i, index) => ({ label: i, color: colorList[index] })) || []
  const visitMap = {
    visitTotal: 12,
    channelList: [
      {
        name: '综治中心',
        number: 3
      },
      {
        name: '信访',
        number: 4
      },
      {
        name: '网格',
        number: 2
      },
      {
        name: '12345热线',
        number: 3
      },
    ],
    identityList: [
      {
        name: '申请方当事人',
        number: 3
      },
      {
        name: '被申请方代理人',
        number: 1
      },
      {
        name: '被申请方代理人',
        number: 2
      },
      {
        name: '被申请方代理人',
        number: 1
      },
    ]
  }

  // 列配置
  const fakeColumns = [
    {
      title: '时间',
      width: 150,
      dataIndex: 'createTime', defaultSortOrder: 'ascend',
      sorter: { compare: (a, b) => { } }, render: (text) => <div style={{ width: '150px' }}>{$$.minuteFormat(text)}</div>
    },
    {
      title: '数据来源',
      width: 100,
      dataIndex: 'canalName',
      key: 'canalName',
    },
    {
      title: '事项状态',
      width: 100,
      dataIndex: 'statusName',
      key: 'statusName',
    },
    {
      title: '化解结果',
      width: 100,
      dataIndex: 'mediResultName',
      key: 'mediResultName',
    },
    {
      title: '事件类型',
      width: 100,
      dataIndex: 'caseTypeName',
      key: 'caseTypeName',
    },
    {
      title: '问题属地',
      width: 100,
      dataIndex: 'areaName',
      key: 'areaName',
    },
    {
      title: '事项来源',
      width: 100,
      dataIndex: 'canalName',
      key: 'canalName',
    },
    {
      title: '事项等级',
      width: 100,
      dataIndex: 'caseLevel',
      key: 'caseLevel',
    },
    {
      title: '申请方',
      width: 100,
      dataIndex: 'plaintiffs',
      key: 'plaintiffs',
    },
    {
      title: '被申请方',
      width: 100,
      dataIndex: 'defendants',
      key: 'defendants',
    },
    {
      title: '操作',
      dataIndex: 'perClassName',
      key: 'perClassName',
      width: 100,
      fixed: 'right',
      render: (_, record) => (
        <div style={{ display: 'flex', color: '#1A6FB8', gap: '16px' }}>
          <div onClick={() => window.open(`${$$.windowUrl}/windowDetail?caseTaskId=${record.caseTaskId}&caseId=${record.id}`)} className="public-a">详情</div>
        </div>
      )
    },
  ];

  return (
    <div>
      {
        tagList?.length > 0 &&
        <>
          <Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '8px' }}>
            <Space size='small'>
              <div className='MediationInfo-subTitle' ></div><span style={{ fontWeight: '600' }}>重点人员标签</span>
            </Space>
          </Col>
          <Space style={{ marginBottom: '20px' }}>
            {tagList?.map((item, index) => (
              <div key={index} className="dialogTag" style={{ backgroundColor: item.color }}>{item.label}</div>
            ))}
          </Space>
        </>
      }
      <Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '8px' }}>
        <Space size='small'>
          <div className='MediationInfo-subTitle' ></div><span style={{ fontWeight: '600' }}>反映诉求记录</span>
        </Space>
      </Col>
      <div style={{ marginBottom: '12px' }}>
        <div><span>来访总数： </span><span style={{ color: '#1a6fb8' }}>{data?.totalNum || 0}</span> 次</div>
        <div><span>来访渠道： </span>
          <span>综治中心<span style={{ color: '#1a6fb8' }}>{data?.zzzxNum || 0}</span>次</span>、
          <span>信访<span style={{ color: '#1a6fb8' }}>{data?.xfNum || 0}</span>次</span>、
          <span>网格<span style={{ color: '#1a6fb8' }}>{data?.wlNum || 0}</span>次</span>、
          <span>12345热线<span style={{ color: '#1a6fb8' }}>{data?.ottfNum || 0}</span>次</span></div>
        <div><span>来访身份：</span>
          <span >申请方当事人：<span style={{ color: '#1a6fb8' }}>{data?.plaintiffNum || 0}</span>次</span>、
          <span >申请方代理人：<span style={{ color: '#1a6fb8' }}>{data?.pagentsNum || 0}</span>次</span>、
          <span >被申请方当事人：<span style={{ color: '#1a6fb8' }}>{data?.defendantNum || 0}</span>次</span>、
          <span >被申请方代理人：<span style={{ color: '#1a6fb8' }}>{data?.dagentsNum || 0}</span>次</span>
        </div>
      </div>
      <TableView
        columns={fakeColumns}
        dataSource={fakeData.tableData}
        size="small"
        rowKey="id"
        bordered={true}
        style={{ marginBottom: '60px' }}
        className='visitTableClass'
        scroll={{ x: 1300 }}
        onChange={(pagination, filters, sorter) => {
          handleChangePage(pagination.current, pagination.pageSize, sorter.field, sorter.order)
        }}
        pagination={{
          current: search.page,
          pageSize: search.size,
          total: fakeData.total,
        }}
      />
    </div>
  )
}
